@@ -1,5 +1,5 @@
 package Playwright;
-$Playwright::VERSION = '0.007';
+$Playwright::VERSION = '0.008';
 use strict;
 use warnings;
 
@@ -15,7 +15,6 @@ use LWP::UserAgent();
 use Sub::Install();
 use Net::EmptyPort();
 use JSON::MaybeXS();
-use File::Slurper();
 use File::Which();
 use Capture::Tiny qw{capture_merged capture_stderr};
 use Carp qw{confess};
@@ -111,7 +110,8 @@ sub _build_classes {
             return $class->new(
                 handle => $self,
                 id     => $res->{_guid},
-                type   => $class
+                type   => $class,
+                parent => $self,
             );
         };
 
@@ -240,8 +240,7 @@ sub launch ( $self, %args ) {
 }
 
 sub await ( $self, $promise ) {
-    confess("Input must be an AsyncData") unless $promise->isa('AsyncData');
-    my $obj = $promise->result(1);
+    my $obj = Playwright::Util::await($promise);
 
     return $obj unless $obj->{_type};
     my $class = "Playwright::$obj->{_type}";
@@ -322,7 +321,7 @@ Playwright - Perl client for Playwright
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
@@ -444,8 +443,8 @@ L<https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Functions/ar
 
 =head2 Asynchronous operations
 
-The waitFor* methods defined on various classes will return an instance of AsyncData, a part of the L<Async> module.
-You will then need to wait on the result of the backgrounded action with the await() method documented below.
+The waitFor* methods defined on various classes are essentially a light wrapper around Mojo::IOLoop::Subprocess.
+You will need to wait on the result of the backgrounded action with the await() method documented below.
 
     # Assuming $handle is a Playwright object
     my $async = $page->waitForEvent('console');
@@ -453,6 +452,23 @@ You will then need to wait on the result of the backgrounded action with the awa
     my $result = $handle->await( $async );
     my $logged = $result->text();
 
+=head2 Getting Object parents
+
+Some things, like elements naturally are children of the pages in which they are found.
+Sometimes this can get confusing when you are using multiple pages, especially if you let the ref to the page go out of scope.
+Don't worry though, you can access the parent attribute on most Playwright::* objects:
+
+    # Assuming $element is a Playwright::ElementHandle
+    my $page = $element->{parent};
+
+=head2 Firefox Specific concerns
+
+By default, firefox will open PDFs in a pdf.js window.
+To suppress this behavior (such as in the event you are await()ing a download event), you will have to pass this option to launch():
+
+    # Assuming $handle is a Playwright object
+    my $browser = $handle->launch( type => 'firefox', firefoxUserPrefs => { 'pdfjs.disabled' => JSON::true } );
+
 =head1 INSTALLATION NOTE
 
 If you install this module from CPAN, you will likely encounter a croak() telling you to install node module dependencies.
@@ -480,7 +496,7 @@ L<https://playwright.dev/docs/api/class-browsertype#browsertypelaunchoptions>
 
 There is an additional "special" argument, that of 'type', which is used to specify what type of browser to use, e.g. 'firefox'.
 
-=head2 await (AsyncData) = Object
+=head2 await (HASH) = Object
 
 Waits for an asynchronous operation returned by the waitFor* methods to complete and returns the value.
 
